@@ -1,27 +1,25 @@
 # _*_coding:utf-8_*_
 
-import os, logging, time, json, copy
-import re
-import jwt
-from datetime import datetime, timedelta
-
-from django.contrib.auth.hashers import make_password
-from main.settings import BASE_DIR
+import logging
 from pathlib import Path
+import re
+
+from django.db.models import Q
+from rest_framework import generics
 from rest_framework import response
 from rest_framework import serializers
-from rest_framework import generics
-from rest_framework.permissions import IsAuthenticated, IsAdminUser, AllowAny
-from django.db.models import Q
+from rest_framework.permissions import AllowAny
 
-from xj_role.services.user_group_service import UserGroupService
-from ..services.user_detail_info_service import DetailInfoService
+from main.settings import BASE_DIR
 from xj_role.services.role_service import RoleService
+from xj_role.services.user_group_service import UserGroupService
 from ..models import *
+from ..services.user_detail_info_service import DetailInfoService
 from ..services.user_service import UserService
-from ..utils.model_handle import parse_data, model_delete
+from ..utils.custom_response import util_response
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
+from ..utils.model_handle import parse_data
 
 module_root = str(Path(__file__).resolve().parent)
 # 配置之对象
@@ -91,13 +89,15 @@ class UserEdit(generics.UpdateAPIView):  # 或继承(APIView)
             # print("> token:", token)
 
             if not token:
-                raise MyApiError('缺少Token', 6001)
+                # raise MyApiError('缺少Token', 6001)
+                return util_response('', 7557, "缺少Token")
 
             # 判断token是否失效
             t_auth = Auth.objects.filter(token=token).order_by('-update_time').first()
             # print("> t_auth:", t_auth)
             if not t_auth:
-                raise MyApiError('token失效', 6002)
+                # raise MyApiError('token失效', 6002)
+                return util_response('', 7557, "token失效")
 
             # 如果有用户ID则找到该ID，没有则修改自己的ID
             # print("> self.params['user_id']:", self.params)
@@ -163,92 +163,46 @@ class UserEdit(generics.UpdateAPIView):  # 或继承(APIView)
         token = request.META.get('HTTP_AUTHORIZATION', '')
         token_serv, error_text = UserService.check_token(token)
         if error_text:
-            raise MyApiError(error_text, 6010)
+            # raise MyApiError(error_text, 6010)
+            return util_response(err=6002, msg=error_text)
             # 判断token是否失效
         if re.match(r'Bearer(.*)$', token, re.IGNORECASE):
             token = re.match(r'Bearer(.*)$', token, re.IGNORECASE).group(1).strip()
         t_auth = Auth.objects.filter(token=token).order_by('-update_time').first()
-        # print("> t_auth:", t_auth)
         if not t_auth:
-            raise MyApiError('token失效', 6002)
+            # raise MyApiError('token失效', 6002)
+            return util_response(err=6002, msg="token失效")
 
         # 如果有用户ID则找到该ID，没有则修改自己的ID
-        # print("> self.params['user_id']:", self.params)
         if 'user_id' in self.params:
             user_id = self.params.get('user_id', '')
         else:
             user_id = t_auth.user_id
-        # print("> user_id:", user_id)
         # 添加逻辑
         try:
-            account = str(self.params.get('account', ''))
-            # password = str(self.params.get('password', ''))
-            phone = str(self.params.get('phone', ''))
+
+            user_name = str(self.params.get('user_name', ''))
             full_name = str(self.params.get('full_name', ''))
             nickname = str(self.params.get('nickname', ''))
-            avatar = str(self.params.get('avatar', ''))
-
+            phone = str(self.params.get('phone', ''))
             # 用户角色部门绑定
             user_role_list = self.params.get('user_role_list', None)
             user_group_list = self.params.get('user_group_list', None)
 
-            # 边界检查
-            # if not account:
-            #     raise MyApiError("account必填", 2001)
+            base_info = {}
+            if user_name:
+                base_info['user_name'] = user_name
+                is_exists = BaseInfo.objects.filter(Q(user_name=user_name), ~Q(id=user_id)).exists()
+                if is_exists:
+                    return util_response('', 7557, "用户名已存在")
+            if full_name:
+                base_info['full_name'] = full_name
+            if nickname:
+                base_info['nickname'] = nickname
+            if phone:
+                base_info['phone'] = phone
 
-            # if not password:
-            #     raise MyApiError("password必填", 2003)
-
-            # if not full_name:
-            #     raise MyApiError("full_name必填", 2008)
-            base_info = {
-                'full_name': full_name,
-                "nickname": nickname,
-            }
-            if account:
-                # 账号类型判断
-                if re.match(r'(^1[356789]\d{9}$)|(^\+?[78]\d{10}$)', account):
-                    account_type = 'phone'
-                elif re.match(r'^\w+[\w\.\-\_]*@\w+[\.\w]*\.\w{2,}$', account):
-                    account_type = 'email'
-                elif re.match(r'^[A-z\u4E00-\u9FA5]+\w*$', account):
-                    account_type = 'username'
-                else:
-                    raise MyApiError("账号必须是用户名、手机或者邮箱，用户名不能是数字开头", 2009)
-
-                # 检查账号是否存在
-                user_list = None
-                if account_type == 'phone':
-                    user_list = BaseInfo.objects.filter(Q(phone=account), ~Q(id=user_id))
-                elif account_type == 'email':
-                    user_list = BaseInfo.objects.filter(Q(email=account), ~Q(id=user_id))
-                elif account_type == 'username':
-                    user_list = BaseInfo.objects.filter(Q(user_name=account), ~Q(id=user_id))
-                if user_list.count() and account_type == 'phone':
-                    raise MyApiError("手机已被注册: " + account)
-                elif user_list.count() and account_type == 'email':
-                    raise MyApiError("邮箱已被注册: " + account)
-                elif user_list.count() and account_type == 'username':
-                    raise MyApiError("用户名已被注册: " + account)
-
-                # # 检查平台是否存在
-                # platform_id = None
-                # platform_set = Platform.objects.filter(platform_name__iexact=platform)
-                # if not platform_set.count() == 0:
-                #     platform_id = platform_set.first().platform_id
-
-                base_info = {
-                    'user_name': account if account_type == 'username' else '',
-                    'full_name': full_name,
-                    "nickname": nickname,
-                    'phone': account if account_type == 'phone' else phone,
-                    'email': account if account_type == 'email' else '',
-                }
-            # detail_info = {
-            #     "avatar":avatar
-            # }
-
-            current_user = BaseInfo.objects.filter(id=user_id).update(**base_info)
+            BaseInfo.objects.filter(id=user_id).update(**base_info)
 
             if detaili.get("user_name"):
                 del detaili['user_name']
@@ -261,16 +215,18 @@ class UserEdit(generics.UpdateAPIView):  # 或继承(APIView)
                 del detaili['phone']
             if detaili.get("email"):
                 del detaili['email']
+            if detaili.get("user_role_list"):
+                del detaili['user_role_list']
+            if detaili.get("user_group_list"):
+                del detaili['user_group_list']
+            detaili = DetailInfoService.transform_params(detaili)
+            detailinfo = DetailInfo.objects.filter(user_id=user_id).first()
+            if detailinfo:
+                DetailInfo.objects.filter(user_id=user_id).update(**detaili)
+            else:
+                detaili['user_id'] = user_id
+                DetailInfo.objects.create(**detaili)
 
-            DetailInfo.objects.filter(user_id=user_id).update(**detaili)
-            # token = jwt.encode({'account': account}, jwt_secret_key)
-            # auth = {
-            #     'user_id': user_id,
-            #     'password': make_password(password, None, 'pbkdf2_sha1'),
-            #     'plaintext': password,
-            #     'token': token,
-            # }
-            # Auth.objects.create(**auth)
             # 用户绑定权限和部门
             if user_group_list:
                 UserGroupService.bind_user_group(user_id, user_group_list)
@@ -305,11 +261,22 @@ class UserEdit(generics.UpdateAPIView):  # 或继承(APIView)
                 'msg': '未知错误'
             }
 
-        return response.Response(data=res, status=None, template_name=None, headers={"Authorization": token},
-                                 content_type=None)
+        return response.Response(data=res, status=None, template_name=None, headers={"Authorization": token}, content_type=None)
 
     def delete(self, request, *args, **kwargs):
-        return model_delete(request, BaseInfo)
+        # return model_delete(request, BaseInfo)
+        from_data = parse_data(request)
+        if not 'id' in from_data.keys():
+            return util_response('', 7557, "ID不能为空")
+        res = BaseInfo.objects.filter(id=from_data['id'])
+        if not res:
+            return util_response('', 7557, "数据不存在")
+
+        detailinfo = DetailInfo.objects.filter(user_id=from_data['id']).first()
+        if detailinfo:
+            DetailInfo.objects.filter(user_id=from_data['id']).delete()
+        res.delete()
+        return util_response()
 
 
 class MyApiError(Exception):
