@@ -1,13 +1,8 @@
-import json
-
-from django.http import HttpResponse
+from django.core.cache import cache
 from rest_framework import response
 from rest_framework.views import APIView
-from django.core.cache import cache
 
-from xj_user.utils.model_handle import parse_data
-from ..services.user_service import UserService
-from xj_user.services.wechat_service import WechatService
+from ..utils.model_handle import parse_data
 from ..services.user_sms_service import UserSmsService
 from ..utils.custom_response import util_response
 
@@ -27,7 +22,7 @@ class ShortMessageLogin(APIView):
         cache_code = cache.get(phone)
         if code == cache_code:
             app = UserSmsService()
-            err, data = app.phone_login(phone=phone, login_code=login_code, sso_serve_id=sso_serve_id)
+            err, data = app.phone_login(phone=phone, login_code=login_code, sso_serve_id=sso_serve_id, detail_params=params)
             if err == 0:
                 return util_response(data=data)
             else:
