@@ -1,8 +1,8 @@
 from django.db.models import F
 from rest_framework.response import Response
 
-from xj_user.models import ContactBook
-from xj_user.utils.custom_response import util_response
+from ..models import ContactBook
+from ..utils.custom_response import util_response
 
 
 class ContactBookService:
