@@ -1,29 +1,27 @@
 # _*_coding:utf-8_*_
 
 from datetime import datetime, timedelta
+from pathlib import Path
 # import os, logging, time, json, copy
 import re
 
-from django.contrib.auth.hashers import make_password
-from pathlib import Path
-
-from django.forms import model_to_dict
-
-from main.settings import BASE_DIR
 from django.contrib.auth.hashers import check_password
+from django.contrib.auth.hashers import make_password
 from django.core.paginator import Paginator
 from django.db.models import Q, F
+from django.forms import model_to_dict
 import jwt
 # from django.db.models import F
 # from rest_framework import exceptions
 from rest_framework import serializers
 
-from config.config import Config
-from ..models import Auth, DetailInfo
+from config.config import JConfig as MainConfig
+from main.settings import BASE_DIR
+from ..models import Auth, DetailInfo, ExtendField, Platform
 from ..models import BaseInfo
+from ..utils.custom_tool import filter_result_field
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
-from ..utils.model_handle import format_params_handle
 
 module_root = str(Path(__file__).resolve().parent)
 # 配置之对象
@@ -36,6 +34,8 @@ jwt_secret_key = main_config_dict.jwt_secret_key or module_config_dict.jwt_secre
 expire_day = main_config_dict.expire_day or module_config_dict.expire_day or ""
 expire_second = main_config_dict.expire_second or module_config_dict.expire_second or ""
 
+config = MainConfig()
+
 
 class UserInfoSerializer(serializers.ModelSerializer):
     # 方法一：使用SerializerMethodField，并写出get_platform, 让其返回你要显示的对象就行了
@@ -108,8 +108,6 @@ class UserService:
         # 用户ID
         user_list = BaseInfo.objects.filter(Q(user_name=account) | Q(phone=account) | Q(email=account)) \
             .annotate(user_id=F("id")) \
-            .annotate(user_group_value=F("user_group__group")) \
-            .annotate(permission_value=F("permission__permission_name")) \
             .values(
             'user_id',
             'user_name',
@@ -121,8 +119,8 @@ class UserService:
             'user_info',
             # 'user_group_id',
             # 'user_group_value',
-            'permission_id',
-            'permission_value'
+            # 'permission_id',
+            # 'permission_value'
         )
         if not user_list.count():
             return None, "账户不存在"
@@ -137,13 +135,22 @@ class UserService:
 
     # 验证密码
     @staticmethod
-    def check_login(user_id, password, account):
+    def check_login(user_id, password, account, platform):
         """
         @param user_id 用户ID
         @param password 用户密码。
         @param account 登陆账号，必填，用于生成Token令牌。
         @description 注意：目前密码是明文传输，今后都要改成密文传输
         """
+        # 检查平台是否存在
+        platform_id = ""
+        if platform:
+            platform_set = Platform.objects.filter(platform_name__iexact=platform)
+            if platform_set.count() is 0:
+                return None, "platform不存在平台名称：" + platform
+                # raise MyApiError("platform不存在平台名称："+platform, 2009)
+            platform_id = platform_set.first().platform_id
+
         auth_set = Auth.objects.filter(user_id=user_id, password__isnull=False).order_by('-update_time').first()
         if not auth_set:
             return None, "账户尚未开通登录服务：" + account + "(" + str(user_id) + ")"
@@ -162,8 +169,9 @@ class UserService:
         expire_timestamp = datetime.utcnow() + timedelta(days=7, seconds=0)
         # 为本次登录生成Token并记录
         # todo 漏洞，当用户修改用户名时，并可能导致account失效，是否存用户ID更好
-        token = jwt.encode(payload={'account': account, 'user_id': user_id, "exp": expire_timestamp},
-                           key=jwt_secret_key)
+        token = jwt.encode(
+            payload={'account': account, 'user_id': user_id, 'platform_id': platform_id, 'exp': expire_timestamp},
+            key=jwt_secret_key)
         # payload = jwt.decode(token, key=Config.getIns().get('xj_user', 'JWT_SECRET_KEY', ""), verify=True, algorithms=["RS256", "HS256"])
         # print("> payload:", payload)
         auth_set.token = token
@@ -253,7 +261,7 @@ class UserService:
         try:
             # jwt.decode会自动检查exp参数，如果超时则抛出jwt.ExpiredSignatureError超时
             # jwt_payload = jwt.decode(token, key=Config.getIns().get('xj_user', 'JWT_SECRET_KEY'), verify=True, algorithms=["RS256", "HS256"])
-            jwt_payload = jwt.decode(token, key=Config.getIns().get('xj_user', 'JWT_SECRET_KEY', '@zxmxy2021!'),
+            jwt_payload = jwt.decode(token, key=config.get('xj_user', 'JWT_SECRET_KEY', '@zxmxy2021!'),
                                      verify=True, algorithms=["RS256", "HS256"])
             # print("> jwt_payload:", jwt_payload)
 
@@ -265,13 +273,14 @@ class UserService:
 
         account = jwt_payload.get('account', None)
         user_id = jwt_payload.get('user_id', None)
+        platform_id = jwt_payload.get('platform_id', None)
         if not account:
             return {'payload': jwt_payload}, "错误：令牌载荷中未提供用户账户Account"
 
         # 检测用户令牌时不应该调用用户信息，这会导致任何接口都会查询用户表，时间会增加
         # user_info = UserService.check_account(account=account)
 
-        return {'account': account, 'user_id': user_id}, None
+        return {'account': account, 'user_id': user_id, 'platform_id': platform_id}, None
 
     # 用户信息列表
     @staticmethod
@@ -415,24 +424,43 @@ class UserService:
         # 用户信息列表
 
     @staticmethod
-    def user_basic_message(user_id=None, nickname=None):
-        # user_basic_message = BaseInfo.objects.filter(id=user_id).first()
+    def user_basic_message(user_id=None, nickname=None, need_detail_info=True):
+        # 查找是否存在该用户
         res_data = {}
         if user_id:
             user_basic_message = BaseInfo.objects.filter(id=user_id).annotate(user_id=F("id")).first()
         elif nickname:
             user_basic_message = BaseInfo.objects.filter(nickname=nickname).annotate(user_id=F("id")).first()
-        if user_basic_message:
-            res_data = model_to_dict(user_basic_message)
-            detailinfo = DetailInfo.objects.filter(user_id=user_id).first()
-            avatar = None
-            if detailinfo:
-                detail_info = model_to_dict(detailinfo)
-                avatar = detail_info['avatar']
-            res_data['avatar'] = avatar
-            res_data['user_id'] = user_id
-        # res_data = user_basic_message.values("id", "user_name", "nickname", "full_name", "phone", "email",
-        #                                      "register_time")
+        else:
+            # 没有输入搜索条件，非法调用直接返回空字典
+            return res_data, None
+
+        # 没有该用户的基础信息，是一个不存在的用户
+        if not user_basic_message:
+            return res_data, None
+
+        # 找到该用户的基础信息
+        res_data = model_to_dict(user_basic_message)
+
+        # 不需要拼接详细信息则直接返回
+        if not need_detail_info:
+            return res_data, None
+
+        # 拼接基础信息和用户详细信息
+        detail_info = DetailInfo.objects.filter(user_id=user_id).first()
+        if detail_info:
+            extend_field_list = ExtendField.objects.all().values("field_index", "field")
+            extend_field_map = {item["field_index"]: item["field"] for item in list(extend_field_list)}
+            detail_info = model_to_dict(detail_info)
+            [detail_alias_info] = filter_result_field(
+                [detail_info],
+                filter_filed_list=[i.name for i in DetailInfo._meta.fields if not i.name[0:6] == "field_"] + list(
+                    extend_field_map.keys()),
+                alias_dict=extend_field_map,
+            )
+            res_data.update(detail_alias_info)
+
+        # 返回基础和详细信息
         return res_data, None
 
     @staticmethod
@@ -509,7 +537,7 @@ class UserService:
 
     @staticmethod
     def user_role_edit(params):
-        # 修改逻辑
+        # 修改逻辑 TODO 为什么起这个名字，这个不是用户基础信息修改吗 BaseInfo.objects.filter(id=user_id).update(**base_info)
         try:
             account = str(params.get('account', ''))
             phone = str(params.get('phone', ''))
