@@ -21,8 +21,8 @@ class UserSsoServeService:
             return {"contact_book_id": user_sso_serve.id}, None
 
     @staticmethod
-    def user_sso_to_user(user_id):
-        res_set = UserSsoToUser.objects.filter(user_id=user_id).first()
+    def user_sso_to_user(user_id, app_id):
+        res_set = UserSsoToUser.objects.filter(user_id=user_id, app_id=app_id).first()
         if res_set:
             return res_set, None
         return None, "单点登录记录不存在"
