@@ -7,22 +7,21 @@
 @created_time: 2022/7/7 9:38
 """
 from datetime import datetime, timedelta
+from pathlib import Path
 
 from django.contrib.auth.hashers import make_password
 import jwt
 import redis
 import requests
-from pathlib import Path
-
-from django.forms import model_to_dict
 
 from main.settings import BASE_DIR
-
-from config.config import Config
-from ..models import BaseInfo, Auth, UserSsoToUser
-from ..utils.model_handle import parse_model
+from xj_role.services.role_service import RoleService
+from .user_detail_info_service import DetailInfoService
+from ..models import BaseInfo, Auth, UserSsoToUser, UserRelateToUser
+from ..services.user_relate_service import UserRelateToUserService
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
+from ..utils.model_handle import parse_model
 from ..utils.nickname_generate import gen_one_word_digit
 
 module_root = str(Path(__file__).resolve().parent)
@@ -88,13 +87,16 @@ class WechatService:
         # except Exception as e:
         #     return 6445, '请求错误'
 
-    def wechat_login(self, phone_code, login_code, sso_serve_id=None):
+    def wechat_login(self, phone_code, login_code, sso_serve_id=None, detail_params=None):
         """
         过期续约就是重新登录
+        :param detail_params:
         :param code: 换取手机号码的code
         :return:(err,data)
         """
         # code 换取手机号
+        if detail_params is None:
+            detail_params = {}
         url = self.wx_get_phone_url + "?access_token={}".format(self.get_access_token()['access_token'])
         header = {'content-type': 'application/json'}
         response = requests.post(url, json={'code': phone_code}, headers=header).json()
@@ -125,11 +127,18 @@ class WechatService:
         # }
         # Auth.objects.update_or_create({'user_id': current_user.get('id', None)}, **auth)
         # return 0, {'token': token, 'user_info': current_user}
+
+        # 通过换取的手机号判断用户是否存在
         current_user = BaseInfo.objects.filter(phone=phone).filter()
         current_user = parse_model(current_user)
-        if login_code:
-            wechat_openid = self.get_openid(code=login_code)
+        if not login_code:
+            return None, "微信登录 login_code 必传"
+        wechat_openid = self.get_openid(code=login_code)
+        if wechat_openid.get("openid", None) is None:
+            return None, "获取 openid 失败 查openid是否过期"
+        # 登录即注册操作
         if not current_user:
+            # 用户不存在的时候，进行注册用户
             base_info = {
                 'user_name': '',
                 'nickname': gen_one_word_digit(),
@@ -144,7 +153,14 @@ class WechatService:
             current_user = current_user[0]
             # 生成登录token
             token = self.__set_token(current_user.get('id', None), phone)
+            # 用户第一次登录即注册，允许添加用户的详细信息
+            try:
+                detail_params.setdefault("user_id", current_user.get('id', None))
+                data, err = DetailInfoService.create_or_update_detail(detail_params)
+            except Exception as e:
+                pass
 
+            # 创建单点登录
             if sso_serve_id:
                 sso_data = {
                     "sso_serve_id": sso_serve_id,
@@ -153,7 +169,6 @@ class WechatService:
                     "app_id": sub_appid
                 }
                 UserSsoToUser.objects.create(**sso_data)
-
             # 创建用户登录信息，绑定token
             auth = {
                 'user_id': current_user.get('id', None),
@@ -162,28 +177,81 @@ class WechatService:
                 'token': token,
             }
             Auth.objects.update_or_create({'user_id': current_user.get('id', None)}, **auth)
-            auth_set = Auth.objects.filter(user_id=current_user.get('id', None), password__isnull=False).order_by(
-                '-update_time').first()
-            return 0, {'token': auth_set.token, 'user_info': current_user}
-        current_user = current_user[0]
-        sso = UserSsoToUser.objects.filter(user_id=current_user.get('id', None)).first()
-        if not sso:
-            if sso_serve_id:
-                sso_data = {
-                    "sso_serve_id": sso_serve_id,
+            auth_set = Auth.objects.filter(user_id=current_user.get('id', None), password__isnull=False).order_by('-update_time').first()
+
+
+        else:
+            # 用户存在的时候
+            current_user = current_user[0]
+            sso = UserSsoToUser.objects.filter(user_id=current_user.get('id', None), app_id=sub_appid).first()
+            if not sso:
+                if sso_serve_id:
+                    sso_data = {
+                        "sso_serve_id": sso_serve_id,
+                        "user_id": current_user.get('id', None),
+                        "sso_unicode": wechat_openid['openid'],
+                        "app_id": sub_appid
+                    }
+                    UserSsoToUser.objects.create(**sso_data)
+            token = self.__set_token(current_user.get('id', None), phone)
+            # 创建用户登录信息，绑定token
+            auth = {
+                'token': token,
+            }
+            Auth.objects.filter(user_id=current_user.get('id', None)).update(**auth)
+            auth_set = Auth.objects.filter(
+                user_id=current_user.get('id', None),
+                password__isnull=False
+            ).order_by('-update_time').first()
+
+        # 绑定用户关系 邀请关系和收益关系
+        print("执行绑定用户关系")
+        try:
+            inviter_id = detail_params.get("inviter_id")
+            if not inviter_id:
+                raise Exception("没有传递邀请人ID无法绑定邀请人")
+
+            # 判断是否是一个有效的用户ID-->>> 有效则之际昂顶邀请人关系
+            inviter = BaseInfo.objects.filter(id=inviter_id).first()
+            if not inviter:
+                raise Exception("没有该用户")
+            data, err = UserRelateToUserService.add(
+                {
                     "user_id": current_user.get('id', None),
-                    "sso_unicode": wechat_openid['openid'],
-                    "app_id": sub_appid
+                    "with_user_id": inviter_id,
+                    "user_relate_type_id": 1
                 }
-                UserSsoToUser.objects.create(**sso_data)
-        token = self.__set_token(current_user.get('id', None), phone)
-        # 创建用户登录信息，绑定token
-        auth = {
-            'token': token,
-        }
-        Auth.objects.filter(user_id=current_user.get('id', None)).update(**auth)
-        auth_set = Auth.objects.filter(user_id=current_user.get('id', None), password__isnull=False).order_by(
-            '-update_time').first()
+            )
+            if err:
+                raise Exception(err)
+
+            # 查询邀请人的受益人是谁，如果存在，直接绑定。
+            saler = UserRelateToUser.objects.filter(user_id=inviter_id, user_relate_type_id=2).first()
+            if saler:
+                data, err = UserRelateToUserService.add(
+                    {
+                        "user_id": current_user.get('id', None),
+                        "with_user_id": inviter_id,
+                        "user_relate_type_id": 2
+                    }
+                )
+                raise Exception("ok")
+
+            # 邀请人不存在受益人，如果是业务则受益人也是邀请人
+            res, err = RoleService.is_this_role(user_id=inviter_id, role_key="BID-SALESMAN")  # 如果是业务人员
+            if res:
+                data, err = UserRelateToUserService.add(
+                    {
+                        "user_id": current_user.get('id', None),
+                        "with_user_id": inviter_id,
+                        "user_relate_type_id": 2
+                    }
+                )
+                raise Exception("ok")
+        except Exception as e:
+            print("e:", e)
+            pass
+
         return 0, {'token': auth_set.token, 'user_info': current_user}
 
     def __set_token(self, user_id, account):
