@@ -6,18 +6,16 @@ Created on 2022-01-17
 from django.http import JsonResponse
 from rest_framework import status
 
-
 # 数据返回规则
+from .custom_tool import parse_json
+
+
 def util_response(data='', err=0, msg='ok', http_status=status.HTTP_200_OK, cookie=None):
     if http_status == status.HTTP_200_OK:
-        return JsonResponse({'err': err, 'msg': msg, 'data': data or {}})
+        return JsonResponse({'err': err, 'msg': msg, 'data': parse_json(data) or {}})
     else:
         print("> util_response:", http_status)
         return JsonResponse({'err': http_status, 'msg': msg, }, status=http_status)
-    if cookie and isinstance(cookie, dict):
-        for k, v in cookie.items():
-            response.set_cookie(k, v)
-    return response
 
 
 # 自定义错误页面时返回【DEBUG为True时生效】
